/*
   .........CKBlue Presents .......Parboti Analog Watch.............
   ..............MODEL : M_008.....................................
   ...Author : Chandan Kumar Mondal................................
   .........Date : 24.04.2020...............
   .....Modified : 12.09.2020...(use RTC)
*/

//.....Library Section.............
#include <SPFD5408_Adafruit_GFX.h>
#include <SPFD5408_Adafruit_TFTLCD.h>
#include <Wire.h>
#include <TimeLib.h>
#include <DS1307RTC.h>
#include <Fonts/myfontfive.h>
#include <Fonts/myfonttwo.h>
#include <Fonts/fontseven.h> //Lato_Regular_7 (sooo small)

//....Object Section..............
Adafruit_TFTLCD tft(A3, A2, A1, A0, A4);

//...Color....
#define face_color BLACK
#define background WHITE

#define  BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF
#define GREY    0x5AEB

//....Global Varialble Section...
int miniutes, hours, myhours, seconds, omx = 120, omy = 120, osx = 120, osy = 120, ohx = 120, ohy = 120,oosx=120, oosy=120, oomx = 120, oomy =120, oohx = 120, oohy =120;
float sdeg, mdeg, hdeg, sx, sy, mx, my, hx, hy;
uint32_t current_time;
boolean clock_start = true;

void setup() {
  tft.reset();
  tft.begin(0x9341);
  tft.setRotation(1);
  tft.fillScreen(BLACK);
  Serial.begin(9600);
  tmElements_t tm;

  while(!RTC.read(tm)){
     tft.setCursor(tft.width()/2-50, tft.width()/2);
     tft.print("Conncting to RTC..");
  }

  seconds = tm.Second;
  miniutes = tm.Minute;
  myhours = tm.Hour;
  make_clock_face();

  if (myhours > 12) {
    hours = myhours - 12;
  } else {
    hours = myhours;
    if (myhours == 0) {
      hours = 12;
    }
  }
  current_time = millis();
}

void loop() {
  if (current_time + 1000 < millis()) {
    current_time = millis();
    // update
    seconds++;
    if (seconds > 59) {
      seconds = 0;
      miniutes++;
      if (miniutes > 59) {
        miniutes = 0;
        hours ++;
        if (hours > 12) {
          hours = 1;
        }
      }
    }

    // Calculation...
    sdeg = seconds * 6;
    mdeg = miniutes * 6 + sdeg*0.01666667;
    hdeg = hours * 30 + mdeg*0.083333333;

    sx = cos(radians(sdeg-90));
    sy = sin(radians(sdeg-90));

    mx = cos(radians(mdeg-90));
    my = sin(radians(mdeg-90));

    hx = cos(radians(hdeg-90));
    hy = sin(radians(hdeg-90));

    // Refresh..
    if(clock_start || seconds==0){
      clock_start = false;
      tft.drawLine(oomx,oomy, omx, omy, background);
      tft.fillCircle(omx,omy,2,background);
      omx = tft.width()/2 + 60*mx;
      omy = tft.height()/2 + 60*my;
      oomx = tft.width()/2 + 10*mx;
      oomy = tft.height()/2 + 10*my;

      tft.drawLine(oohx,oohy, ohx, ohy, background);
      tft.fillCircle(ohx,ohy,2,background);
      ohx = tft.width()/2 + 45*hx;
      ohy = tft.height()/2 + 45*hy;
      oohx = tft.width()/2 + 10*hx;
      oohy = tft.height()/2 + 10*hy;
    }

    tft.drawLine(oosx,oosy, osx, osy, background);
    tft.fillCircle(osx,osy, 2,background);
    osx = tft.width()/2 + 70*sx;
    osy = tft.height()/2 + 70*sy;
    oosx = tft.width()/2 + 10*sx;
    oosy = tft.height()/2 + 10*sy;

    tft.drawLine(oomx,oomy, omx, omy, face_color);
    tft.fillCircle(omx,omy,2,face_color);
    tft.drawLine(oohx,oohy, ohx, ohy, face_color);
    tft.fillCircle(ohx,ohy,2,face_color);
    tft.drawLine(oosx,oosy, osx, osy, face_color);
    tft.fillCircle(osx,osy,2,face_color);

    tft.fillCircle(tft.width()/2, tft.height()/2, 3, face_color);
    tft.drawCircle(tft.width()/2, tft.height()/2 ,6, face_color);
    tft.setCursor((tft.width()/2)-35, (tft.height()/2)+40);
    tft.drawRoundRect((tft.width()/2)-42, (tft.height()/2)+25, 90,20,6,face_color);
    tft.print("CHANDAN");
  }
}

void make_clock_face() {
  tft.fillScreen(0X9880);
  //tft.setFont(&Roboto_Mono_Medium_16);
  tft.setFont(&Lato_Regular_7);
  tft.setTextColor(face_color);
  tft.fillCircle(tft.width() / 2, tft.height() / 2, 105, face_color);
  tft.fillCircle(tft.width() / 2, tft.height() / 2, 95, background);
  int digit = 1;
  for (int i = 0; i < 360; i += 6) {
    if (i % 30 == 0) {
      tft.drawLine(tft.width() / 2 + 105 * cos(radians(i)), tft.height() / 2 + 105 * sin(radians(i)),tft.width() / 2 + 95 * cos(radians(i)), tft.height() / 2 + 95 * sin(radians(i)),background);
    } else {
      tft.fillCircle(tft.width() / 2 + 100 * cos(radians(i)), tft.height() / 2 + 100 * sin(radians(i)), 2, background);
    }

    if(i%30==0){
      tft.setCursor((tft.width() / 2)  + 85 * cos(radians(i-60)), (tft.height() / 2) + 5 + 85 * sin(radians(i-60)));
      tft.print(digit);
      digit+=1;
    }
  }
  tft.setFont();
  tft.setTextColor(face_color);
  tft.setCursor(260,220);
  tft.print("CHANDAN");
  tft.setFont(&Roboto_Mono_Medium_16);
  //tft.fillCircle(tft.width()/2, tft.height()/2, 5, face_color);
}
